==> rc-ui-lib-0.1.47.tgz: package/es/popup/__test__/index.spec.js <==
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import React from 'react';
import { mount } from 'enzyme';
import { Popup } from '..';
describe('Popup', function () {
  it('should lazy render content by default', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
    var wrapper;
    return _regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            wrapper = mount( /*#__PURE__*/React.createElement(Popup, null, /*#__PURE__*/React.createElement("div", {
              className: "foo"
            })));
            expect(wrapper.find('.foo').exists()).toBeFalsy();
            _context.next = 4;
            return wrapper.setProps({
              visible: true
            });

          case 4:
            expect(wrapper.find('.foo').exists()).toBeTruthy();

          case 5:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  })));
  it('should change z-index when using z-index prop', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee2() {
    var wrapper;
    return _regeneratorRuntime.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            wrapper = mount(
            /*#__PURE__*/
            // <Popup visible zIndex={10} />);
            React.createElement(Popup, {
              visible: true,
              style: {
                zIndex: 10
              }
            }));
            expect(wrapper.find('.rc-popup').getDOMNode().style.zIndex).toEqual('10');
            expect(wrapper.find('.rc-overlay').getDOMNode().style.zIndex).toEqual('10');

          case 3:
          case "end":
            return _context2.stop();
        }
      }
    }, _callee2);
  }))); // it('should lock scroll when visibled', async () => {
  //   const wrapper = mount(<Popup />);
  //   expect(document.body.classList.contains('rc-overflow-hidden')).toBeFalsy();
  //   await wrapper.setProps({ visible: true });
  //   expect(document.body.classList.contains('rc-overflow-hidden')).toBeTruthy();
  // });

  it('should allow to using teleport prop', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee3() {
    var div;
    return _regeneratorRuntime.wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            div = document.createElement('div');
            mount( /*#__PURE__*/React.createElement(Popup, {
              visible: true,
              teleport: div
            }));
            expect(div.querySelector('.rc-popup')).toBeTruthy();

          case 3:
          case "end":
            return _context3.stop();
        }
      }
    }, _callee3);
  })));
  it('should render overlay by default', function () {
    var wrapper = mount( /*#__PURE__*/React.createElement(Popup, {
      visible: true
    }));
    expect(wrapper.find('.rc-overlay').exists()).toBeTruthy();
  });
  it('should not render overlay when overlay prop is false', function () {
    var wrapper = mount( /*#__PURE__*/React.createElement(Popup, {
      visible: true,
      overlay: false
    }));
    expect(wrapper.hasClass('rc-overlay'));
  });
  it('should emit click-overlay event when overlay is clicked', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee4() {
    var onClickOverlay, wrapper, overlay;
    return _regeneratorRuntime.wrap(function _callee4$(_context4) {
      while (1) {
        switch (_context4.prev = _context4.next) {
          case 0:
            onClickOverlay = jest.fn();
            wrapper = mount( /*#__PURE__*/React.createElement(Popup, {
              visible: true,
              onClickOverlay: onClickOverlay
            }));
            overlay = wrapper.find('.rc-overlay');
            overlay.simulate('click');
            expect(onClickOverlay).toHaveBeenCalled();

          case 5:
          case "end":
            return _context4.stop();
        }
      }
    }, _callee4);
  })));
  it('should emit open event when visible prop is set to true', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee5() {
    var onOpen, wrapper;
    return _regeneratorRuntime.wrap(function _callee5$(_context5) {
      while (1) {
        switch (_context5.prev = _context5.next) {
          case 0:
            onOpen = jest.fn();
            wrapper = mount( /*#__PURE__*/React.createElement(Popup, {
              visible: false,
              onOpen: onOpen
            }));
            _context5.next = 4;
            return wrapper.setProps({
              visible: true
            });

          case 4:
            expect(onOpen).toHaveBeenCalledTimes(1);

          case 5:
          case "end":
            return _context5.stop();
        }
      }
    }, _callee5);
  })));
  it('should emit close event when visible prop is set to false', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee6() {
    var onClickOverlay, onClose, wrapper, overlay;
    return _regeneratorRuntime.wrap(function _callee6$(_context6) {
      while (1) {
        switch (_context6.prev = _context6.next) {
          case 0:
            onClickOverlay = jest.fn();
            onClose = jest.fn();
            wrapper = mount( /*#__PURE__*/React.createElement(Popup, {
              visible: true,
              onClickOverlay: onClickOverlay,
              onClose: onClose
            }));
            overlay = wrapper.find('.rc-overlay');
            _context6.next = 6;
            return overlay.simulate('click');

          case 6:
            wrapper.setProps({
              visible: false
            });
            expect(onClose).toHaveBeenCalled();

          case 8:
          case "end":
            return _context6.stop();
        }
      }
    }, _callee6);
  })));
  it('should change duration when using duration prop', function () {
    var wrapper = mount( /*#__PURE__*/React.createElement(Popup, {
      visible: true,
      duration: 500
    }));
    var popup = wrapper.find('.rc-popup');
    var overlay = wrapper.find('.rc-overlay');
    expect(popup.getDOMNode().style.animationDuration).toEqual('500ms');
    expect(overlay.getDOMNode().style.animationDuration).toEqual('500ms');
  });
  it('should have "rc-popup--round" class when setting the round prop', function () {
    var wrapper = mount( /*#__PURE__*/React.createElement(Popup, {
      visible: true,
      round: true
    }));
    expect(wrapper.find('.rc-popup--round').exists()).toBeTruthy();
  });
  it('should render close icon when using closeable prop', function () {
    var wrapper = mount( /*#__PURE__*/React.createElement(Popup, {
      visible: true,
      closeable: true
    }));
    expect(wrapper.find('.rc-popup__close-icon').exists()).toBeTruthy();
  });
  it('should emit click-close-icon event when close icon is clicked', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee7() {
    var onClickCloseIcon, wrapper, icon;
    return _regeneratorRuntime.wrap(function _callee7$(_context7) {
      while (1) {
        switch (_context7.prev = _context7.next) {
          case 0:
            onClickCloseIcon = jest.fn();
            wrapper = mount( /*#__PURE__*/React.createElement(Popup, {
              visible: true,
              closeable: true,
              closeIcon: "success",
              onClickCloseIcon: onClickCloseIcon
            }));
            icon = wrapper.find('.rc-popup__close-icon').at(0);
            _context7.next = 5;
            return icon.simulate('click');

          case 5:
            expect(onClickCloseIcon).toHaveBeenCalled();

          case 6:
          case "end":
            return _context7.stop();
        }
      }
    }, _callee7);
  })));
  it('should render correct close icon when using close-icon prop', function () {
    var wrapper = mount( /*#__PURE__*/React.createElement(Popup, {
      visible: true,
      closeable: true,
      closeIcon: "success"
    }));
    expect(wrapper.find('.rc-popup__close-icon')).toMatchSnapshot();
  });
  it('should change icon class prefix when using icon-prefix prop', function () {
    var wrapper = mount( /*#__PURE__*/React.createElement(Popup, {
      visible: true,
      closeable: true,
      iconPrefix: "my-icon"
    }));
    expect(wrapper.html()).toMatchSnapshot();
  });
  it('should allow to prevent close with before-close prop', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee8() {
    var onClickOverlay, www, overlay;
    return _regeneratorRuntime.wrap(function _callee8$(_context8) {
      while (1) {
        switch (_context8.prev = _context8.next) {
          case 0:
            onClickOverlay = jest.fn();
            www = mount( /*#__PURE__*/React.createElement(Popup, {
              visible: true,
              beforeClose: function beforeClose() {
                return false;
              },
              onClickOverlay: onClickOverlay
            }));
            overlay = www.find('.rc-overlay');
            overlay.simulate('click');
            expect(overlay).toBeTruthy();
            _context8.next = 7;
            return www.setProps({
              beforeClose: function beforeClose() {
                return true;
              }
            });

          case 7:
            overlay.simulate('click');
            expect(overlay.exists());

          case 9:
          case "end":
            return _context8.stop();
        }
      }
    }, _callee8);
  })));
  it('should not call before-close when visible prop becomes false', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee9() {
    var beforeClose, wrapper;
    return _regeneratorRuntime.wrap(function _callee9$(_context9) {
      while (1) {
        switch (_context9.prev = _context9.next) {
          case 0:
            beforeClose = jest.fn();
            wrapper = mount( /*#__PURE__*/React.createElement(Popup, {
              visible: true,
              beforeClose: beforeClose
            }));
            _context9.next = 4;
            return wrapper.setProps({
              visible: false
            });

          case 4:
            expect(beforeClose).toHaveBeenCalledTimes(0);

          case 5:
          case "end":
            return _context9.stop();
        }
      }
    }, _callee9);
  })));
});

==> rc-ui-lib-0.1.50.tgz: package/es/popup/__test__/index.spec.js <==
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import React from 'react';
import { mount } from 'enzyme';
import { Popup } from '..';
describe('Popup', function () {
  var wrapper;
  afterEach(function () {
    wrapper.unmount();
    jest.restoreAllMocks();
  });
  it('should change z-index when using z-index prop', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
    return _regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            wrapper = mount( /*#__PURE__*/React.createElement(Popup, {
              visible: true,
              style: {
                zIndex: 1500
              }
            }));
            expect(wrapper.find('.rc-popup').getDOMNode().style.zIndex).toEqual('1500');
            expect(wrapper.find('.rc-overlay').getDOMNode().style.zIndex).toEqual('1500');

          case 3:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  })));
  it('should lock scroll when visibled', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee2() {
    return _regeneratorRuntime.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            wrapper = mount( /*#__PURE__*/React.createElement(Popup, null));
            expect(document.body.classList.contains('rc-overflow-hidden')).toBeFalsy();
            _context2.next = 4;
            return wrapper.setProps({
              visible: true
            });

          case 4:
            expect(document.body.classList.contains('rc-overflow-hidden')).toBeTruthy();

          case 5:
          case "end":
            return _context2.stop();
        }
      }
    }, _callee2);
  })));
  it('should allow to using teleport prop', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee3() {
    var div;
    return _regeneratorRuntime.wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            div = document.createElement('div');
            wrapper = mount( /*#__PURE__*/React.createElement(Popup, {
              visible: true,
              teleport: div
            }));
            expect(div.querySelector('.rc-popup')).toBeTruthy();

          case 3:
          case "end":
            return _context3.stop();
        }
      }
    }, _callee3);
  })));
  it('should render overlay by default', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Popup, {
      visible: true
    }));
    expect(wrapper.find('.rc-overlay')).toBeTruthy();
  });
  it('should not render overlay when overlay prop is false', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Popup, {
      visible: true,
      overlay: false
    }));
    expect(wrapper.hasClass('rc-overlay')).toBeFalsy();
  });
  it('should emit click-overlay event when overlay is clicked', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee4() {
    var onClickOverlay, overlay;
    return _regeneratorRuntime.wrap(function _callee4$(_context4) {
      while (1) {
        switch (_context4.prev = _context4.next) {
          case 0:
            onClickOverlay = jest.fn();
            wrapper = mount( /*#__PURE__*/React.createElement(Popup, {
              visible: true,
              onClickOverlay: onClickOverlay
            }));
            overlay = wrapper.find('.rc-overlay');
            overlay.simulate('click');
            expect(onClickOverlay).toHaveBeenCalled();

          case 5:
          case "end":
            return _context4.stop();
        }
      }
    }, _callee4);
  })));
  it('should emit open event when visible prop is set to true', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee5() {
    var onOpen;
    return _regeneratorRuntime.wrap(function _callee5$(_context5) {
      while (1) {
        switch (_context5.prev = _context5.next) {
          case 0:
            onOpen = jest.fn();
            wrapper = mount( /*#__PURE__*/React.createElement(Popup, {
              visible: false,
              onOpen: onOpen
            }));
            _context5.next = 4;
            return wrapper.setProps({
              visible: true
            });

          case 4:
            expect(onOpen).toHaveBeenCalledTimes(1);

          case 5:
          case "end":
            return _context5.stop();
        }
      }
    }, _callee5);
  })));
  it('should emit close event when visible prop is set to false', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee6() {
    var onClickOverlay, onClose, overlay;
    return _regeneratorRuntime.wrap(function _callee6$(_context6) {
      while (1) {
        switch (_context6.prev = _context6.next) {
          case 0:
            onClickOverlay = jest.fn();
            onClose = jest.fn();
            wrapper = mount( /*#__PURE__*/React.createElement(Popup, {
              visible: true,
              onClickOverlay: onClickOverlay,
              onClose: onClose
            }));
            overlay = wrapper.find('.rc-overlay');
            _context6.next = 6;
            return overlay.simulate('click');

          case 6:
            wrapper.setProps({
              visible: false
            });
            expect(onClose).toHaveBeenCalled();

          case 8:
          case "end":
            return _context6.stop();
        }
      }
    }, _callee6);
  })));
  it('should change duration when using duration prop', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Popup, {
      visible: true,
      duration: 500
    }));
    var popup = wrapper.find('.rc-popup');
    var overlay = wrapper.find('.rc-overlay');
    expect(popup.getDOMNode().style.animationDuration).toEqual('500ms');
    expect(overlay.getDOMNode().style.animationDuration).toEqual('500ms');
  });
  it('should have "rc-popup--round" class when setting the round prop', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Popup, {
      visible: true,
      round: true
    }));
    expect(wrapper.find('.rc-popup--round').exists()).toBeTruthy();
  });
  it('should render close icon when using closeable prop', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Popup, {
      visible: true,
      closeable: true
    }));
    expect(wrapper.find('.rc-popup__close-icon').exists()).toBeTruthy();
  });
  it('should emit click-close-icon event when close icon is clicked', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee7() {
    var onClickCloseIcon, icon;
    return _regeneratorRuntime.wrap(function _callee7$(_context7) {
      while (1) {
        switch (_context7.prev = _context7.next) {
          case 0:
            onClickCloseIcon = jest.fn();
            wrapper = mount( /*#__PURE__*/React.createElement(Popup, {
              visible: true,
              closeable: true,
              closeIcon: "success",
              onClickCloseIcon: onClickCloseIcon
            }));
            icon = wrapper.find('.rc-popup__close-icon').at(0);
            _context7.next = 5;
            return icon.simulate('click');

          case 5:
            expect(onClickCloseIcon).toHaveBeenCalled();

          case 6:
          case "end":
            return _context7.stop();
        }
      }
    }, _callee7);
  })));
  it('should render correct close icon when using close-icon prop', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Popup, {
      visible: true,
      closeable: true,
      closeIcon: "success"
    }));
    expect(wrapper.find('.rc-popup__close-icon')).toMatchSnapshot();
  });
  it('should change icon class prefix when using icon-prefix prop', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Popup, {
      visible: true,
      closeable: true,
      iconPrefix: "my-icon"
    }));
    expect(wrapper.html()).toMatchSnapshot();
  });
  it('should allow to prevent close with before-close prop', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee8() {
    var onClickOverlay, overlay;
    return _regeneratorRuntime.wrap(function _callee8$(_context8) {
      while (1) {
        switch (_context8.prev = _context8.next) {
          case 0:
            onClickOverlay = jest.fn();
            wrapper = mount( /*#__PURE__*/React.createElement(Popup, {
              visible: true,
              beforeClose: function beforeClose() {
                return false;
              },
              onClickOverlay: onClickOverlay
            }));
            overlay = wrapper.find('.rc-overlay');
            overlay.simulate('click');
            expect(overlay).toBeTruthy();
            _context8.next = 7;
            return wrapper.setProps({
              beforeClose: function beforeClose() {
                return true;
              }
            });

          case 7:
            overlay.simulate('click');
            expect(overlay.exists());

          case 9:
          case "end":
            return _context8.stop();
        }
      }
    }, _callee8);
  })));
  it('should not call before-close when visible prop becomes false', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee9() {
    var beforeClose;
    return _regeneratorRuntime.wrap(function _callee9$(_context9) {
      while (1) {
        switch (_context9.prev = _context9.next) {
          case 0:
            beforeClose = jest.fn();
            wrapper = mount( /*#__PURE__*/React.createElement(Popup, {
              visible: true,
              beforeClose: beforeClose
            }));
            _context9.next = 4;
            return wrapper.setProps({
              visible: false
            });

          case 4:
            expect(beforeClose).toHaveBeenCalledTimes(0);

          case 5:
          case "end":
            return _context9.stop();
        }
      }
    }, _callee9);
  })));
});
